@@ -82,20 +82,21 @@ MessageEditor::MessageEditor(MultiDataModel *dataModel, QMainWindow *parent)
 
     // Signals
 #ifndef QT_NO_CLIPBOARD
-    connect(qApp->clipboard(), SIGNAL(dataChanged()),
-            SLOT(clipboardChanged()));
+    connect(qApp->clipboard(), &QClipboard::dataChanged,
+            this, &MessageEditor::clipboardChanged);
 #endif
-    connect(m_dataModel, SIGNAL(modelAppended()),
-            SLOT(messageModelAppended()));
-    connect(m_dataModel, SIGNAL(modelDeleted(int)),
-            SLOT(messageModelDeleted(int)));
-    connect(m_dataModel, SIGNAL(allModelsDeleted()),
-            SLOT(allModelsDeleted()));
-    connect(m_dataModel, SIGNAL(languageChanged(int)),
-            SLOT(setTargetLanguage(int)));
+    connect(m_dataModel, &MultiDataModel::modelAppended,
+            this, &MessageEditor::messageModelAppended);
+    connect(m_dataModel, &MultiDataModel::modelDeleted,
+            this, &MessageEditor::messageModelDeleted);
+    connect(m_dataModel, &MultiDataModel::allModelsDeleted,
+            this, &MessageEditor::allModelsDeleted);
+    connect(m_dataModel, &MultiDataModel::languageChanged,
+            this, &MessageEditor::setTargetLanguage);
 
     m_tabOrderTimer.setSingleShot(true);
-    connect(&m_tabOrderTimer, SIGNAL(timeout()), SLOT(reallyFixTabOrder()));
+    connect(&m_tabOrderTimer, &QTimer::timeout,
+            this, &MessageEditor::reallyFixTabOrder);
 
 #ifndef QT_NO_CLIPBOARD
     clipboardChanged();
@@ -106,6 +107,12 @@ MessageEditor::MessageEditor(MultiDataModel *dataModel, QMainWindow *parent)
     showNothing();
 }
 
+MessageEditor::~MessageEditor()
+{
+    if (FormatTextEdit *fte = qobject_cast<FormatTextEdit *>(m_selectionHolder))
+        disconnect(fte, &FormatTextEdit::editorDestroyed, this, &MessageEditor::editorDestroyed);
+}
+
 void MessageEditor::setupEditorPage()
 {
     QFrame *editorPage = new QFrame;
@@ -114,14 +121,14 @@ void MessageEditor::setupEditorPage()
     m_source = new FormWidget(tr("Source text"), false);
     m_source->setHideWhenEmpty(true);
     m_source->setWhatsThis(tr("This area shows the source text."));
-    connect(m_source, SIGNAL(selectionChanged(QTextEdit*)),
-            SLOT(selectionChanged(QTextEdit*)));
+    connect(m_source, &FormWidget::selectionChanged,
+            this, &MessageEditor::selectionChanged);
 
     m_pluralSource = new FormWidget(tr("Source text (Plural)"), false);
     m_pluralSource->setHideWhenEmpty(true);
     m_pluralSource->setWhatsThis(tr("This area shows the plural form of the source text."));
-    connect(m_pluralSource, SIGNAL(selectionChanged(QTextEdit*)),
-            SLOT(selectionChanged(QTextEdit*)));
+    connect(m_pluralSource, &FormWidget::selectionChanged,
+            this, &MessageEditor::selectionChanged);
 
     m_commentText = new FormWidget(tr("Developer comments"), false);
     m_commentText->setHideWhenEmpty(true);
@@ -129,19 +136,19 @@ void MessageEditor::setupEditorPage()
     m_commentText->setWhatsThis(tr("This area shows a comment that"
                         " may guide you, and the context in which the text"
                         " occurs.") );
-    connect(m_commentText, SIGNAL(selectionChanged(QTextEdit*)),
-            SLOT(selectionChanged(QTextEdit*)));
+    connect(m_commentText, &FormWidget::selectionChanged,
+            this, &MessageEditor::selectionChanged);
 
     QBoxLayout *subLayout = new QVBoxLayout;
 
-    subLayout->setMargin(5);
+    subLayout->setContentsMargins(5, 5, 5, 5);
     subLayout->addWidget(m_source);
     subLayout->addWidget(m_pluralSource);
     subLayout->addWidget(m_commentText);
 
     m_layout = new QVBoxLayout;
     m_layout->setSpacing(2);
-    m_layout->setMargin(2);
+    m_layout->setContentsMargins(2, 2, 2, 2);
     m_layout->addLayout(subLayout);
     m_layout->addStretch(1);
     editorPage->setLayout(m_layout);
@@ -191,15 +198,17 @@ void MessageEditor::messageModelAppended()
                         " They have no effect on the translated applications.") );
     ed.transCommentText->getEditor()->installEventFilter(this);
     ed.transCommentText->getEditor()->setVisualizeWhitespace(m_visualizeWhitespace);
-    connect(ed.transCommentText, SIGNAL(selectionChanged(QTextEdit*)),
-            SLOT(selectionChanged(QTextEdit*)));
-    connect(ed.transCommentText, SIGNAL(textChanged(QTextEdit*)),
-            SLOT(emitTranslatorCommentChanged(QTextEdit*)));
-    connect(ed.transCommentText, SIGNAL(textChanged(QTextEdit*)), SLOT(resetHoverSelection()));
-    connect(ed.transCommentText, SIGNAL(cursorPositionChanged()), SLOT(resetHoverSelection()));
+    connect(ed.transCommentText, &FormWidget::selectionChanged,
+            this, &MessageEditor::selectionChanged);
+    connect(ed.transCommentText, &FormWidget::textChanged,
+            this, &MessageEditor::emitTranslatorCommentChanged);
+    connect(ed.transCommentText, &FormWidget::textChanged,
+            this, &MessageEditor::resetHoverSelection);
+    connect(ed.transCommentText, &FormWidget::cursorPositionChanged,
+            this, &MessageEditor::resetHoverSelection);
     fixTabOrder();
     QBoxLayout *box = new QVBoxLayout(ed.container);
-    box->setMargin(5);
+    box->setContentsMargins(5, 5, 5, 5);
     box->addWidget(ed.transCommentText);
     box->addSpacing(ed.transCommentText->getEditor()->fontMetrics().height() / 2);
     m_layout->addWidget(ed.container);
@@ -208,7 +217,7 @@ void MessageEditor::messageModelAppended()
 
 void MessageEditor::allModelsDeleted()
 {
-    foreach (const MessageEditorData &med, m_editors)
+    for (const MessageEditorData &med : qAsConst(m_editors))
         med.container->deleteLater();
     m_editors.clear();
     m_currentModel = -1;
@@ -244,7 +253,8 @@ void MessageEditor::messageModelDeleted(int model)
 void MessageEditor::addPluralForm(int model, const QString &label, bool writable)
 {
     FormMultiWidget *transEditor = new FormMultiWidget(label);
-    connect(transEditor, SIGNAL(editorCreated(QTextEdit*)), SLOT(editorCreated(QTextEdit*)));
+    connect(transEditor, &FormMultiWidget::editorCreated,
+            this, &MessageEditor::editorCreated);
     transEditor->setEditingEnabled(writable);
     transEditor->setHideWhenEmpty(!writable);
     if (!m_editors[model].transTexts.isEmpty())
@@ -253,12 +263,14 @@ void MessageEditor::addPluralForm(int model, const QString &label, bool writable
     static_cast<QBoxLayout *>(m_editors[model].container->layout())->insertWidget(
         m_editors[model].transTexts.count(), transEditor);
 
-    connect(transEditor, SIGNAL(selectionChanged(QTextEdit*)),
-            SLOT(selectionChanged(QTextEdit*)));
-    connect(transEditor, SIGNAL(textChanged(QTextEdit*)),
-            SLOT(emitTranslationChanged(QTextEdit*)));
-    connect(transEditor, SIGNAL(textChanged(QTextEdit*)), SLOT(resetHoverSelection()));
-    connect(transEditor, SIGNAL(cursorPositionChanged()), SLOT(resetHoverSelection()));
+    connect(transEditor, &FormMultiWidget::selectionChanged,
+            this, &MessageEditor::selectionChanged);
+    connect(transEditor, &FormMultiWidget::textChanged,
+            this, &MessageEditor::emitTranslationChanged);
+    connect(transEditor, &FormMultiWidget::textChanged,
+            this, &MessageEditor::resetHoverSelection);
+    connect(transEditor, &FormMultiWidget::cursorPositionChanged,
+            this, &MessageEditor::resetHoverSelection);
 
     m_editors[model].transTexts << transEditor;
 }
@@ -306,9 +318,9 @@ void MessageEditor::fixTabOrder()
 void MessageEditor::reallyFixTabOrder()
 {
     QWidget *prev = this;
-    foreach (const MessageEditorData &med, m_editors) {
-        foreach (FormMultiWidget *fmw, med.transTexts)
-            foreach (QTextEdit *te, fmw->getEditors()) {
+    for (const MessageEditorData &med : qAsConst(m_editors)) {
+        for (FormMultiWidget *fmw : med.transTexts)
+            for (QTextEdit *te : fmw->getEditors()) {
                 setTabOrder(prev, te);
                 prev = te;
             }
@@ -318,7 +330,8 @@ void MessageEditor::reallyFixTabOrder()
     }
 }
 
-/*! internal
+/*
+    \internal
     Returns all translations for an item.
     The number of translations is dependent on if we have a plural form or not.
     If we don't have a plural form, then this should only contain one item.
@@ -347,11 +360,16 @@ void MessageEditor::selectionChanged(QTextEdit *te)
     if (te != m_selectionHolder) {
         if (m_selectionHolder) {
             clearSelection(m_selectionHolder);
-            disconnect(this, SLOT(editorDestroyed()));
+            if (FormatTextEdit *fte = qobject_cast<FormatTextEdit*>(m_selectionHolder)) {
+                disconnect(fte, &FormatTextEdit::editorDestroyed,
+                           this, &MessageEditor::editorDestroyed);
+            }
+        }
+        m_selectionHolder = (te->textCursor().hasSelection() ? te : nullptr);
+        if (FormatTextEdit *fte = qobject_cast<FormatTextEdit*>(m_selectionHolder)) {
+            connect(fte, &FormatTextEdit::editorDestroyed,
+                    this, &MessageEditor::editorDestroyed);
         }
-        m_selectionHolder = (te->textCursor().hasSelection() ? te : 0);
-        if (FormatTextEdit *fte = qobject_cast<FormatTextEdit*>(m_selectionHolder))
-            connect(fte, SIGNAL(editorDestroyed()), SLOT(editorDestroyed()));
 #ifndef QT_NO_CLIPBOARD
         updateCanCutCopy();
 #endif
@@ -370,8 +388,11 @@ void MessageEditor::resetSelection()
 {
     if (m_selectionHolder) {
         clearSelection(m_selectionHolder);
-        disconnect(this, SLOT(editorDestroyed()));
-        m_selectionHolder = 0;
+        if (FormatTextEdit *fte = qobject_cast<FormatTextEdit*>(m_selectionHolder)) {
+            disconnect(fte, &FormatTextEdit::editorDestroyed,
+                       this, &MessageEditor::editorDestroyed);
+        }
+        m_selectionHolder = nullptr;
 #ifndef QT_NO_CLIPBOARD
         updateCanCutCopy();
 #endif
@@ -382,7 +403,7 @@ void MessageEditor::activeModelAndNumerus(int *model, int *numerus) const
 {
     for (int j = 0; j < m_editors.count(); ++j) {
         for (int i = 0; i < m_editors[j].transTexts.count(); ++i)
-            foreach (QTextEdit *te, m_editors[j].transTexts[i]->getEditors())
+            for (QTextEdit *te : m_editors[j].transTexts[i]->getEditors())
                 if (m_focusWidget == te) {
                     *model = j;
                     *numerus = i;
@@ -404,7 +425,7 @@ QTextEdit *MessageEditor::activeTranslation() const
         return 0;
     const QList<FormatTextEdit *> &editors =
             m_editors[m_currentModel].transTexts[m_currentNumerus]->getEditors();
-    foreach (QTextEdit *te, editors)
+    for (QTextEdit *te : editors)
         if (te->hasFocus())
             return te;
     return editors.first();
@@ -470,7 +491,7 @@ MessageEditorData *MessageEditor::modelForWidget(const QObject *o)
 {
     for (int j = 0; j < m_editors.count(); ++j) {
         for (int i = 0; i < m_editors[j].transTexts.count(); ++i)
-            foreach (QTextEdit *te, m_editors[j].transTexts[i]->getEditors())
+            for (QTextEdit *te : m_editors[j].transTexts[i]->getEditors())
                 if (te == o)
                     return &m_editors[j];
         if (m_editors[j].transCommentText->getEditor() == o)
@@ -553,7 +574,7 @@ void MessageEditor::showNothing()
     m_commentText->clearTranslation();
     for (int j = 0; j < m_editors.count(); ++j) {
         setEditingEnabled(j, false);
-        foreach (FormMultiWidget *widget, m_editors[j].transTexts)
+        for (FormMultiWidget *widget : qAsConst(m_editors[j].transTexts))
             widget->clearTranslation();
         m_editors[j].transCommentText->clearTranslation();
     }
@@ -625,9 +646,9 @@ void MessageEditor::showMessage(const MultiDataIndex &index)
             for (int i = 0; i < ed.transTexts.size(); ++i) {
                 bool shouldShow = (i < normalizedTranslations.count());
                 if (shouldShow)
-                    setTranslation(j, normalizedTranslations.at(i), i);
+                    setNumerusTranslation(j, normalizedTranslations.at(i), i);
                 else
-                    setTranslation(j, QString(), i);
+                    setNumerusTranslation(j, QString(), i);
                 ed.transTexts.at(i)->setVisible(i == 0 || shouldShow);
             }
         }
@@ -638,7 +659,7 @@ void MessageEditor::showMessage(const MultiDataIndex &index)
     updateUndoRedo();
 }
 
-void MessageEditor::setTranslation(int model, const QString &translation, int numerus)
+void MessageEditor::setNumerusTranslation(int model, const QString &translation, int numerus)
 {
     MessageEditorData &ed = m_editors[model];
     if (numerus >= ed.transTexts.count())
@@ -668,7 +689,7 @@ void MessageEditor::setTranslation(int latestModel, const QString &translation)
 void MessageEditor::setEditingEnabled(int model, bool enabled)
 {
     MessageEditorData &ed = m_editors[model];
-    foreach (FormMultiWidget *widget, ed.transTexts)
+    for (FormMultiWidget *widget : qAsConst(ed.transTexts))
         widget->setEditingEnabled(enabled);
     ed.transCommentText->setEditingEnabled(enabled);
 
@@ -680,8 +701,8 @@ void MessageEditor::setEditingEnabled(int model, bool enabled)
 void MessageEditor::setLengthVariants(bool on)
 {
     m_lengthVariants = on;
-    foreach (const MessageEditorData &ed, m_editors)
-        foreach (FormMultiWidget *widget, ed.transTexts)
+    for (const MessageEditorData &ed : qAsConst(m_editors))
+        for (FormMultiWidget *widget : ed.transTexts)
             widget->setMultiEnabled(on);
 }
 
@@ -818,7 +839,7 @@ void MessageEditor::setEditorFocus()
             activeEditor->setFocus();
 }
 
-void MessageEditor::setEditorFocus(int model)
+void MessageEditor::setEditorFocusForModel(int model)
 {
     if (m_currentModel != model) {
         if (model < 0) {
@@ -867,10 +888,10 @@ void MessageEditor::setVisualizeWhitespace(bool value)
     m_pluralSource->getEditor()->setVisualizeWhitespace(value);
     m_commentText->getEditor()->setVisualizeWhitespace(value);
 
-    foreach (const MessageEditorData &med, m_editors) {
+    for (const MessageEditorData &med : qAsConst(m_editors)) {
         med.transCommentText->getEditor()->setVisualizeWhitespace(value);
-        foreach (FormMultiWidget *widget, med.transTexts)
-            foreach (FormatTextEdit *te, widget->getEditors())
+        for (FormMultiWidget *widget : med.transTexts)
+            for (FormatTextEdit *te : widget->getEditors())
                 te->setVisualizeWhitespace(value);
     }
 }
@@ -897,9 +918,9 @@ void MessageEditor::applyFontSize()
     m_pluralSource->getEditor()->setFont(font);
     m_commentText->getEditor()->setFont(font);
 
-    foreach (MessageEditorData med, m_editors) {
-        for (int i = 0; i < med.transTexts.count(); ++i)
-            foreach (QTextEdit *te, med.transTexts[i]->getEditors())
+    for (const MessageEditorData &med : qAsConst(m_editors)) {
+        for (FormMultiWidget *fmw : med.transTexts)
+            for (QTextEdit *te : fmw->getEditors())
                 te->setFont(font);
         med.transCommentText->getEditor()->setFont(font);
     }
