@@ -28,11 +28,9 @@
 
 #include "qdoccommandlineparser.h"
 
-#include "loggingcategory.h"
 #include "utilities.h"
 
 #include <QtCore/qdebug.h>
-#include <QtCore/qdir.h>
 #include <QtCore/qfile.h>
 
 QDocCommandLineParser::QDocCommandLineParser()
@@ -46,23 +44,23 @@ QDocCommandLineParser::QDocCommandLineParser()
       noExamplesOption(QStringList() << QStringLiteral("no-examples")),
       indexDirOption(QStringList() << QStringLiteral("indexdir")),
       installDirOption(QStringList() << QStringLiteral("installdir")),
-      obsoleteLinksOption(QStringList() << QStringLiteral("obsoletelinks")),
       outputDirOption(QStringList() << QStringLiteral("outputdir")),
       outputFormatOption(QStringList() << QStringLiteral("outputformat")),
       noLinkErrorsOption(QStringList() << QStringLiteral("no-link-errors")),
       autoLinkErrorsOption(QStringList() << QStringLiteral("autolink-errors")),
       debugOption(QStringList() << QStringLiteral("debug")),
+      atomsDumpOption("atoms-dump"),
       prepareOption(QStringList() << QStringLiteral("prepare")),
       generateOption(QStringList() << QStringLiteral("generate")),
       logProgressOption(QStringList() << QStringLiteral("log-progress")),
       singleExecOption(QStringList() << QStringLiteral("single-exec")),
-      writeQaPagesOption(QStringList() << QStringLiteral("write-qa-pages")),
       includePathOption("I", "Add dir to the include path for header files.", "path"),
       includePathSystemOption("isystem", "Add dir to the system include path for header files.",
                               "path"),
       frameworkOption("F", "Add macOS framework to the include path for header files.",
                       "framework"),
-      timestampsOption(QStringList() << QStringLiteral("timestamps"))
+      timestampsOption(QStringList() << QStringLiteral("timestamps")),
+      useDocBookExtensions(QStringList() << QStringLiteral("docbook-extensions"))
 {
     setApplicationDescription(QCoreApplication::translate("qdoc", "Qt documentation generator"));
     addHelpOption();
@@ -110,10 +108,6 @@ QDocCommandLineParser::QDocCommandLineParser()
     installDirOption.setValueName(QStringLiteral("dir"));
     addOption(installDirOption);
 
-    obsoleteLinksOption.setDescription(QCoreApplication::translate(
-            "qdoc", "Report links from obsolete items to non-obsolete items"));
-    addOption(obsoleteLinksOption);
-
     outputDirOption.setDescription(QCoreApplication::translate(
             "qdoc", "Specify output directory, overrides setting in qdocconf file"));
     outputDirOption.setValueName(QStringLiteral("dir"));
@@ -135,6 +129,11 @@ QDocCommandLineParser::QDocCommandLineParser()
     debugOption.setDescription(QCoreApplication::translate("qdoc", "Enable debug output"));
     addOption(debugOption);
 
+    atomsDumpOption.setDescription(QCoreApplication::translate(
+            "qdoc",
+            "Shows a human-readable form of the intermediate result of parsing a block-comment."));
+    addOption(atomsDumpOption);
+
     prepareOption.setDescription(QCoreApplication::translate(
             "qdoc", "Run qdoc only to generate an index file, not the docs"));
     addOption(prepareOption);
@@ -151,9 +150,6 @@ QDocCommandLineParser::QDocCommandLineParser()
             QCoreApplication::translate("qdoc", "Run qdoc once over all the qdoc conf files."));
     addOption(singleExecOption);
 
-    writeQaPagesOption.setDescription(QCoreApplication::translate("qdoc", "Write QA pages."));
-    addOption(writeQaPagesOption);
-
     includePathOption.setFlags(QCommandLineOption::ShortOptionStyle);
     addOption(includePathOption);
 
@@ -165,6 +161,10 @@ QDocCommandLineParser::QDocCommandLineParser()
     timestampsOption.setDescription(
             QCoreApplication::translate("qdoc", "Timestamp each qdoc log line."));
     addOption(timestampsOption);
+
+    useDocBookExtensions.setDescription(QCoreApplication::translate(
+            "qdoc", "Use the DocBook Library extensions for metadata."));
+    addOption(useDocBookExtensions);
 }
 
 /*!
